@@ -7,28 +7,25 @@ from meloetta.actors.types import State, Choices
 
 
 class RandomActor(Actor):
-    def __init__(self, queue: mp.Queue):
-        self._queue = queue
+    def __init__(self, queue: mp.Queue = None):
+        self.queue = queue
 
     def choose_action(
         self,
         state: State,
         room: BattleRoom,
         choices: Choices,
-        **kwargs,
     ):
         random_key = random.choice([key for key, value in choices.items() if value])
         _, (func, args, kwargs) = random.choice(list(choices[random_key].items()))
-        return func, args, kwargs, None
+        return func, args, kwargs
 
-    def store_reward(
-        self,
-        room: BattleRoom,
-        pid: int,
-        reward: float = None,
-        store_transition: bool = True,
-    ):
-        if reward > 0:
-            self._queue.put(("random", 1))
-        elif reward < 0:
-            self._queue.put(("random", 0))
+    def post_match(self, room: BattleRoom):
+        if self.queue is not None:
+            datum = room.get_reward()
+            reward = datum["reward"]
+
+            if reward > 0:
+                self.queue.put(("random", 1))
+            elif reward < 0:
+                self.queue.put(("random", 0))
